@@ -35,13 +35,17 @@
 #define BUFSIZE 256
 #endif /* HAVE_LIBPURPLE */
 
+#ifdef __MINGW32__
+__MINGW_IMPORT long timezone;
+#endif
+
 struct PlusTag
 {
     char *code;
     int len;
 };
 
-gboolean
+static gboolean
 check_if_first_char_str_is_number (const gchar* str)
 {
     if (strncmp (str, "0", 1) == 0 || strncmp (str, "1", 1) == 0 ||
@@ -905,7 +909,7 @@ pn_html_unescape (const char *url)
                     { "reg", "®" },
                     { "apos", "'" },
                 };
-                int i;
+                unsigned i;
                 for (i = 0; i < ARRAY_SIZE(refs); i++) {
                     struct ref ref = refs[i];
                     int len = strlen(ref.name);
